@@ -3,7 +3,7 @@ Copyright (C) 2009 John Goerzen <jgoerzen@complete.org>
 
 All rights reserved.
 
-For license and copyright information, see the file COPYRIGHT
+For license and copyright information, see the file LICENSE
 -}
 module TestInfrastructure where
 import qualified Test.QuickCheck as QC
@@ -13,5 +13,3 @@ import Test.HUnit.Tools
 q :: QC.Testable a => String -> a -> HU.Test
 q = qc2hu 250
 
-qverbose :: QC.Testable a => String -> a -> HU.Test
-qverbose = qc2huVerbose 250
\ No newline at end of file
